/**
 * Theme Customizer enhancements for a better user experience.
 *
 * Contains handlers to make Theme Customizer preview reload changes asynchronously.
 */

( function( $ ) {
	var api = wp.customize;
	// Site title and description.
	api( 'blogname', function( value ) {
		value.bind( function( to ) {
			$( '.site-title' ).text( to );
		} );
	} );
	api( 'blogdescription', function( value ) {
		value.bind( function( to ) {
			$( '.site-description' ).text( to );
		} );
	} );

	// Body font size
	api( 'body', function( value ) {
		value.bind( function( to ) {
			$( 'body' ).css( 'font-size', to + "px" );
			console.log(to);
		} );
	} );
	api( 'header', function( value ) {
		value.bind( function( to ) {
			$( 'h1' ).css( 'font-size', to + "px" );
			console.log(to);
		} );
	} );

	// Accent color
	api( 'accent', function( value ) {
		value.bind( function( to ) {
			$( 'a' ).not('.post-content a, .site-header a, .more-link, .entry-title a').css( 'color', to );
			$( '.more-link' ).css( 'background-color', to );
		} );
	} );

	// Background Color
	api( 'background_color', function( value ) {
		value.bind( function( to ) {
			$( 'body' ).css( 'background-color', to );
		} );
	} );
	// Background Opacity
	api( 'background-opacity', function( value ) {
		value.bind( function( to ) {
			$( '.page-cover' ).css( 'opacity', to );
		} );
	} );

	// Footer copyright text
	api( 'copyright', function( value ) {
		value.bind( function( to ) {
			$( '.site-info' ).html( to );
		} );
	} );

	// Hide tagline
	api( 'hide-tagline', function( value ) {
		value.bind( function( to ) {
			if ( to ) {
				$( '.site-description' ).hide();
			} else {
				$( '.site-description' ).css('display', 'inline-block');
			}
		} );
	} );

	// Hide read more links
	api( 'read-more', function( value ) {
		value.bind( function( to ) {
			if ( to ) {
				$( '.read-more' ).hide();
			} else {
				$( '.read-more' ).show();
			}

			// Trigger window resize to fix masonry layout
			$(window).resize();
		} );
	} );
} )( jQuery );
