(function ($) {
	'use strict';

	var Stag = {

		cache: {
			$document: $(document),
			$window: $(window),
			$body: $('body'),
			$navToggle: $('#site-navigation-toggle'),
			$isiPod: (/(iPhone|iPod)/g).test(navigator.userAgent),
			$isSafari: (-1 !== navigator.userAgent.indexOf('Safari') && -1 === navigator.userAgent.indexOf('Chrome')),
		},

		init: function () {
			this.bindEvents();
		},

		bindEvents: function () {
			var self = this;

			this.cache.$document.on('ready', function () {
				self.navigationInit();
				self.masonryInit();
				self.setupResponsiveSlides();
				self.postLikes();
				self.fitText();

				// Set min height for container to fix issue with background not scaling to window height
				self.cache.$windowHeight = (true === self.cache.isiPod && true === self.cache.isSafari) ? window.screen.availHeight : self.cache.$window.height();
				// $('.container').css('min-height', self.cache.$windowHeight);

				// Trigger window resize to fix masonry layout issue
				self.cache.$window.resize();

				$('.rslides_tabs').on('click', 'li', function () {
					self.cache.$window.trigger('resize');
				});

				$('.page-cover').imagesLoaded({
					background: true
				}, function () {
					$('.page-cover').css({
						'animation': 'zoom-out 900ms ease-out',
						'transform': 'scale(1)',
					});
				});
			});



		},

		/**
		 * Initialize the mobile menu functionality.
		 *
		 * @since 1.0.0.
		 *
		 * @return {void}
		 */
		navigationInit: function () {
			var openClass = 'site-nav-transition site-nav-drawer-open',
				self = this;

			this.cache.$navToggle.on('click', function (e) {
				e.preventDefault();
				self.cache.$body.toggleClass(openClass);
			});

			$('.site-nav-overlay').on('click', function (e) {
				e.preventDefault();
				self.cache.$body.toggleClass(openClass);
			});

			$( '.site-nav--scrollable-container' ).on( 'click', '#close-nav', function(ev) {
				ev.preventDefault();
				self.cache.$body.toggleClass( openClass );
			});
		},

		postLikes: function () {
			$('.post-likes').on('click', function (e) {
				e.preventDefault();

				var $link = $(this),
					$id = $link.attr('id');

				if ($link.hasClass('active')) {
					$link.addClass('invalid');

					setTimeout(function () {
						$link.removeClass('invalid');
					}, 400)

					return false;
				}

				$link.addClass('liked');

				$.post(stag.ajaxurl, {
					action: 'process_post_likes',
					likes_id: $id
				}, function (data) {
					$link.addClass('active').attr('title', stag.alreadyLikeText);
					$link.find('span').text(data.data.post_likes);
				});
			});
		},

		/**
		 * Initialize Masonry.
		 *
		 * @since 1.0.0.
		 *
		 * @return void
		 */
		masonryInit: function () {
			// Make sure lib is loaded
			if (!$.fn.masonry) {
				return;
			}

			var layout = this.cache.$body.data('layout');

			var $container = $('#posts-wrapper'),
				$gutter = $('#gutter-sizer'),
				$masonry,
				lazyLayout;

			var args = {
				gutterWidth: $gutter.outerWidth(),
				gutter: $gutter.outerWidth(),
				itemSelector: '.masonry-post'
			};

			if (layout === "sticky-column") {
				args.columnWidth = 1;
			}

			// Run masonry
			$masonry = $container.masonry(args);

			// Run Masonry again on window resize
			lazyLayout = this.debounce(function () {
				$masonry.masonry({
					gutterWidth: $gutter.outerWidth(),
					gutter: $gutter.outerWidth()
				});
			}, 300);
			this.cache.$window.on('resize', lazyLayout);

			// Trigger resize when all images are loaded
			var _self = this;
			if ($.fn.imagesLoaded) {
				var imgLoad = imagesLoaded($container);

				imgLoad.on('progress', function () {
					_self.cache.$window.trigger('resize');
				});
			}
		},

		setupResponsiveSlides: function () {
			if (!$.fn.responsiveSlides)
				return;

			$('.stag-gallery-slideshow.deactivated').responsiveSlides({
				auto: false,
				nav: true,
				pause: true,
				prevText: '',
				nextText: '',
				pager: true
			}).removeClass('deactivated');
		},

		fitText: function () {
			if (!$.fn.fitText) {
				return;
			}

			$('#error-title').fitText(1, {
				minFontSize: '90px',
				maxFontSize: '200px'
			});
		},

		/**
		 * Throttles an action.
		 *
		 * Taken from Underscore.js.
		 *
		 * @link    http://underscorejs.org/#debounce
		 *
		 * @param   func
		 * @param   wait
		 * @param   immediate
		 * @returns {Function}
		 */
		debounce: function (func, wait, immediate) {
			var timeout, args, context, timestamp, result;
			return function () {
				context = this;
				args = arguments;
				timestamp = new Date();
				var later = function () {
					var last = (new Date()) - timestamp;
					if (last < wait) {
						timeout = setTimeout(later, wait - last);
					} else {
						timeout = null;
						if (!immediate) {
							result = func.apply(context, args);
						}
					}
				};
				var callNow = immediate && !timeout;
				if (!timeout) {
					timeout = setTimeout(later, wait);
				}
				if (callNow) {
					result = func.apply(context, args);
				}
				return result;
			};
		},
	};

	Stag.init();
})(jQuery);
