<?php
/**
 * Ink theme customizer settings.
 *
 * @package Stag_Customizer
 * @subpackage Skilt
 */

function stag_customize_register_sections( $wp_customize ) {
	$wp_customize->get_section( 'background_image' )->priority = 20;

	$wp_customize->get_setting( 'background_image' )->transport = 'refresh';
	$wp_customize->get_setting( 'background_color' )->transport = 'refresh';

	$wp_customize->add_section(
		'general_settings',
		array(
			'title'       => _x( 'General Settings', 'Theme customizer section title', 'skilt' ),
			'priority'    => 30,
			'description' => null,
		)
	);

	$wp_customize->add_section(
		'styling-options',
		array(
			'title'    => _x( 'Styling Options', 'Theme customizer section title', 'skilt' ),
			'priority' => 40,
		)
	);

	$wp_customize->add_section(
		'font',
		array(
			'title'       => _x( 'Fonts', 'Theme customizer section title', 'skilt' ),
			'priority'    => 60,
			'description' => sprintf(
				__( 'The list of Google fonts is long! You can %s before making your choices.', 'skilt' ),
				sprintf(
					'<a href="%1$s" target="_blank">%2$s</a>',
					esc_url( 'https://fonts.google.com' ),
					__( 'preview', 'skilt' )
				)
			),
		)
	);

	$wp_customize->add_section(
		'layout',
		array(
			'title'    => _x( 'Layout', 'Theme customizer section title', 'skilt' ),
			'priority' => 80,
		)
	);

	$wp_customize->add_section(
		'footer',
		array(
			'title'    => _x( 'Footer', 'Theme customizer section title', 'skilt' ),
			'priority' => 900,
		)
	);

	$wp_customize->add_section(
		'404_page',
		array(
			'title'       => _x( '404 Error Page', 'Theme customizer section title', 'skilt' ),
			'priority'    => 910,
			'description' => __( 'Customize 404 error page texts.', 'skilt' ),
		)
	);
}
add_action( 'customize_register', 'stag_customize_register_sections' );

/**
 * Default theme customizations.
 *
 * @return $options an array of default theme options
 */
function stag_get_theme_mods( $args = array() ) {
	$defaults = array(
		'keys_only' => false,
	);

	$args = wp_parse_args( $args, $defaults );

	// Priority for first section
	$priority = new Stag_Prioritizer( 0, 10 );

	// Holds all customizer sections and settings
	$mods = array();

	$mods['general_settings'] = array(
		'logo-regular'            => array(
			'title'             => __( 'Regular Logo', 'skilt' ),
			'type'              => 'Stag_Customize_Image_Control',
			'default'           => null,
			'sanitize_callback' => 'esc_url_raw',
			'priority'          => $priority->add(),
			'transport'         => 'refresh',
		),
		'logo-retina'             => array(
			'title'             => __( 'Retina Logo (2x)', 'skilt' ),
			'type'              => 'Stag_Customize_Image_Control',
			'default'           => null,
			'sanitize_callback' => 'esc_url_raw',
			'description'       => __( 'The Retina Logo should be twice the size of the Regular Logo.', 'skilt' ),
			'priority'          => $priority->add(),
			'transport'         => 'refresh',
		),
		'favicon'                 => array(
			'title'             => __( 'Favicon', 'skilt' ),
			'type'              => 'Stag_Customize_Image_Control',
			'default'           => null,
			'sanitize_callback' => 'esc_url_raw',
			'description'       => __( 'File must be <strong>.png</strong> or <strong>.ico</strong> format. Optimal dimensions: <strong>32px x 32px</strong>.', 'skilt' ),
			'priority'          => $priority->add(),
		),
		'apple-touch-icon'        => array(
			'title'             => __( 'Apple Touch Icon', 'skilt' ),
			'type'              => 'Stag_Customize_Image_Control',
			'default'           => null,
			'sanitize_callback' => 'esc_url_raw',
			'description'       => __( 'File must be <strong>.png</strong> format. Optimal dimensions: <strong>152px x 152px</strong>.', 'skilt' ),
			'priority'          => $priority->add(),
		),
		'contact_email'           => array(
			'title'             => __( 'Contact Form Email Address', 'skilt' ),
			'type'              => 'email',
			'default'           => null,
			'sanitize_callback' => 'sanitize_email',
			'priority'          => $priority->add(),
		),
		'google_analytics_script' => array(
			'title'             => __( 'Google Analytics Tracking Code', 'skilt' ),
			'description'       => __( 'Remember to copy the tracking code with <script> tags.', 'skilt' ),
			'type'              => 'Stag_Customize_Textarea_Control',
			'default'           => false,
			'sanitize_callback' => 'skilt_sanitize_analytics_code',
			'priority'          => $priority->add(),
		),
	);

	$mods['background_image'] = array(
		'background-size'    => array(
			'title'             => esc_html__( 'Background Size', 'skilt' ),
			'type'              => 'radio',
			'default'           => 'cover',
			'sanitize_callback' => 'sanitize_key',
			'choices'           => array(
				'auto'    => esc_html__( 'Auto', 'skilt' ),
				'contain' => esc_html__( 'Contain', 'skilt' ),
				'cover'   => esc_html__( 'Cover', 'skilt' ),
			),
		),
		'background-opacity' => array(
			'title'             => __( 'Background Opacity', 'skilt' ),
			'type'              => 'Stag_Customize_Slider_Control',
			'default'           => '0.8',
			'sanitize_callback' => 'skilt_range_sanitization',
			'choices'           => array(
				'min'  => '0',
				'max'  => '1',
				'step' => '0.1',
			),
			'priority'          => $priority->add(),
		),
		'background-filter'  => array(
			'title'             => __( 'Background (CSS3) Filter', 'skilt' ),
			'type'              => 'select',
			'default'           => 'none',
			'sanitize_callback' => 'sanitize_key',
			'transport'         => 'refresh',
			'choices'           => array(
				'none'       => __( 'None', 'skilt' ),
				'grayscale'  => __( 'Grayscale', 'skilt' ),
				'sepia'      => __( 'Sepia', 'skilt' ),
				'blur'       => __( 'Blur', 'skilt' ),
				'hue-rotate' => __( 'Hue Rotate', 'skilt' ),
				'contrast'   => __( 'Contrast', 'skilt' ),
				'brightness' => __( 'Brightness', 'skilt' ),
				'invert'     => __( 'Invert', 'skilt' ),
			),
			'priority'          => $priority->add(),
		),
	);

	$mods['colors'] = array(
		'accent'                 => array(
			'title'             => esc_html__( 'Accent Color', 'skilt' ),
			'type'              => 'WP_Customize_Color_Control',
			'default'           => '#f56f6c',
			'sanitize_callback' => 'skilt_sanitize_hex_color',
			'priority'          => $priority->add(),
		),
		'header-area-text-color' => array(
			'title'             => esc_html__( 'Header Area Text Color', 'skilt' ),
			'type'              => 'WP_Customize_Color_Control',
			'default'           => '#ffffff',
			'sanitize_callback' => 'skilt_sanitize_hex_color',
			'transport'         => 'refresh',
			'priority'          => $priority->add(),
		),
		'footer-area-text-color' => array(
			'title'             => esc_html__( 'Footer Area Text Color', 'skilt' ),
			'type'              => 'WP_Customize_Color_Control',
			'default'           => '#ffffff',
			'sanitize_callback' => 'skilt_sanitize_hex_color',
			'transport'         => 'refresh',
			'priority'          => $priority->add(),
		),
	);

	$mods['styling-options'] = array(
		'layout'     => array(
			'title'             => __( 'Homepage Layout', 'skilt' ),
			'type'              => 'Stag_Customizer_Layout_Control',
			'default'           => '3-column',
			'sanitize_callback' => 'sanitize_key',
			'choices'           => array(
				'sticky-column' => __( 'Sticky Column', 'skilt' ),
				'3-column'      => __( '3 Column', 'skilt' ),
				'2-column'      => __( '2 Column', 'skilt' ),
				'full-width'    => __( '1 Column (Full Width)', 'skilt' ),
			),
			'transport'         => 'refresh',
			'priority'          => $priority->add(),
		),
		'custom-css' => array(
			'title'             => __( 'Custom CSS', 'skilt' ),
			'type'              => 'Stag_Customize_Textarea_Control',
			'default'           => null,
			'sanitize_callback' => 'sanitize_text_field',
			'transport'         => 'refresh',
			'priority'          => $priority->add(),
		),
	);

	$mods['title_tagline'] = array(
		'hide-tagline' => array(
			'title'             => __( 'Hide Tagline', 'skilt' ),
			'type'              => 'checkbox',
			'default'           => 0,
			'sanitize_callback' => 'wp_validate_boolean',
		),
	);

	$priority->reboot();

	$google_fonts = stag_all_font_choices();

	$mods['font'] = array(
		'header'      => array(
			'title'             => __( 'Headers', 'skilt' ),
			'type'              => 'select',
			'default'           => 'Roboto',
			'sanitize_callback' => 'sanitize_text_field',
			'transport'         => 'refresh',
			'choices'           => $google_fonts,
			'priority'          => $priority->add(),
		),
		'body'        => array(
			'title'             => __( 'Body', 'skilt' ),
			'type'              => 'select',
			'default'           => 'Roboto',
			'sanitize_callback' => 'sanitize_text_field',
			'transport'         => 'refresh',
			'choices'           => $google_fonts,
			'priority'          => $priority->add(),
		),
		'subset'      => array(
			'title'             => __( 'Character Subset', 'skilt' ),
			'type'              => 'select',
			'default'           => 'latin',
			'sanitize_callback' => 'sanitize_key',
			'description'       => __( 'Not all fonts provide each of these subsets.', 'skilt' ),
			'choices'           => stag_get_google_font_subsets(),
			'priority'          => $priority->add(),
		),
		'font-line'   => array(
			'type'              => 'Stag_Customize_Misc_Control',
			'default'           => false,
			'sanitize_callback' => 'sanitize_text_field',
			'option'            => 'line',
			'priority'          => $priority->add(),
		),
		'body-size'   => array(
			'title'             => __( 'Body Font Size (in px)', 'skilt' ),
			'type'              => 'Stag_Customize_Slider_Control',
			'default'           => '17',
			'sanitize_callback' => 'skilt_range_sanitization',
			'choices'           => array(
				'min'  => '12',
				'max'  => '50',
				'step' => '1',
			),
			'priority'          => $priority->add(),
			'transport'         => 'refresh',
		),
		'header-size' => array(
			'title'             => __( 'Header Font Size (in px)', 'skilt' ),
			'type'              => 'Stag_Customize_Slider_Control',
			'default'           => '40',
			'sanitize_callback' => 'skilt_range_sanitization',
			'choices'           => array(
				'min'  => '15',
				'max'  => '75',
				'step' => '1',
			),
			'priority'          => $priority->add(),
			'transport'         => 'refresh',
		),
	);

	$week_ago = date( get_option( 'date_format' ), time() - WEEK_IN_SECONDS );

	$mods['layout'] = array(
		'post-date'           => array(
			'title'             => __( 'Post Date', 'skilt' ),
			'type'              => 'select',
			'transport'         => 'refresh',
			'default'           => 'relative',
			'sanitize_callback' => 'sanitize_key',
			'choices'           => array(
				'absolute' => sprintf( __( 'Absolute (%s)', 'skilt' ), $week_ago ),
				'relative' => __( 'Relative (1 week ago)', 'skilt' ),
				'none'     => __( 'None', 'skilt' ),
			),
			'priority'          => $priority->add(),
		),
		'post-likes'          => array(
			'title'             => __( 'Hide Post Likes', 'skilt' ),
			'type'              => 'checkbox',
			'default'           => 0,
			'sanitize_callback' => 'wp_validate_boolean',
			'transport'         => 'refresh',
			'priority'          => $priority->add(),
		),
		'post-formats'        => array(
			'title'             => __( 'Hide Post Format Icons', 'skilt' ),
			'type'              => 'checkbox',
			'default'           => 0,
			'sanitize_callback' => 'wp_validate_boolean',
			'transport'         => 'refresh',
			'priority'          => $priority->add(),
		),
		'read-more'           => array(
			'title'             => __( 'Hide Read More Link', 'skilt' ),
			'type'              => 'checkbox',
			'default'           => 1,
			'sanitize_callback' => 'wp_validate_boolean',
			'transport'         => 'refresh',
			'priority'          => $priority->add(),
		),
		'post-navigation'     => array(
			'title'             => __( 'Show Next/Previous Navigation', 'skilt' ),
			'type'              => 'checkbox',
			'default'           => 0,
			'sanitize_callback' => 'wp_validate_boolean',
			'transport'         => 'refresh',
			'priority'          => $priority->add(),
		),
		'excerpt-length'      => array(
			'title'             => __( 'Post Excerpt Length (in words)', 'skilt' ),
			'type'              => 'number',
			'default'           => '25',
			'sanitize_callback' => 'absint',
			'transport'         => 'refresh',
			'priority'          => $priority->add(),
		),
		'related-posts-line'  => array(
			'type'              => 'Stag_Customize_Misc_Control',
			'default'           => false,
			'sanitize_callback' => 'sanitize_text_field',
			'option'            => 'line',
			'priority'          => $priority->add(),
		),
		'related-posts-count' => array(
			'title'             => __( 'Number of Related posts to show', 'skilt' ),
			'type'              => 'text',
			'default'           => '3',
			'sanitize_callback' => 'sanitize_text_field',
			'priority'          => $priority->add(),
		),
		'related-posts'       => array(
			'title'             => __( 'Show Related Posts on Single Posts', 'skilt' ),
			'type'              => 'checkbox',
			'default'           => 1,
			'sanitize_callback' => 'wp_validate_boolean',
			'priority'          => $priority->add(),
		),
		'navigation-position' => array(
			'title'             => __( 'Navigation Position', 'skilt' ),
			'type'              => 'select',
			'default'           => 'sidebar',
			'sanitize_callback' => 'sanitize_key',
			'transport'         => 'refresh',
			'choices'           => array(
				'header'  => __( 'Header (Traditional)', 'skilt' ),
				'sidebar' => __( 'Sidebar', 'skilt' ),
			),
			'priority'          => $priority->add(),
		),
	);

	$mods['static_front_page'] = array(
		'show-intro' => array(
			'title'             => __( 'Include an Intro section at the frontpage', 'skilt' ),
			'type'              => 'checkbox',
			'transport'         => 'refresh',
			'default'           => 0,
			'sanitize_callback' => 'wp_validate_boolean',
		),
		'intro-page' => array(
			'title'             => __( 'Intro Page', 'skilt' ),
			'type'              => 'dropdown-pages',
			'default'           => 0,
			'sanitize_callback' => 'skilt_sanitize_dropdown_pages',
			'description'       => __( 'Select the page where the content for the intro section will be pulled from.', 'skilt' ),
		),
	);

	$mods['footer'] = array(
		'copyright' => array(
			'title'             => __( 'Copyright Text', 'skilt' ),
			'type'              => 'Stag_Customize_Textarea_Control',
			'default'           => 'Thanks for using a theme from <a href="//codestag.com">Codestag</a>. You are awesome!',
			'sanitize_callback' => 'sanitize_text_field',
		),
	);

	$mods['404_page'] = array(
		'404-title'       => array(
			'title'             => __( 'Title', 'skilt' ),
			'type'              => 'text',
			'default'           => '404',
			'sanitize_callback' => 'sanitize_text_field',
		),
		'404-description' => array(
			'title'             => __( 'Description', 'skilt' ),
			'type'              => 'Stag_Customize_Textarea_Control',
			'default'           => 'Hey, the thing you have been looking for simply is not here. Perhaps you would want to click a button like the one below, or do something else with your life.',
			'sanitize_callback' => 'sanitize_text_field',
		),
	);

	$mods = apply_filters( 'stag_theme_mods', $mods );

	/** Return all keys within all sections (for transport, etc) */
	if ( $args['keys_only'] ) {
		$transport = array();

		foreach ( $mods as $section => $settings ) {
			foreach ( $settings as $key => $setting ) {
				if ( isset( $setting['transport'] ) ) {
					$transport[ $key ] = $setting['transport'];
				} else {
					$transport[ $key ] = '';
				}
			}
		}

		return $transport;
	}

	return $mods;
}

/**
 * Layout Picker Control
 *
 * Attach the custom layout picker control to the `customize_register` action
 * so the WP_Customize_Control class is initiated.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 * @return void
 */
function stag_customizer_layout_control( $wp_customize ) {
	class Stag_Customizer_Layout_Control extends WP_Customize_Control {
		public $type = 'layout';

		public function render_content() {

			$img_dir = get_template_directory_uri() . '/assets/img/';
			?>
			<span class="customize-control-title"><?php echo esc_html( $this->label ); ?></span>
				<ul>
			<?php

			foreach ( $this->choices as $key => $value ) {
				?>
				<li class="customizer-control-row">
					<input type="radio" value="<?php echo esc_attr( $key ); ?>" name="<?php echo esc_attr( $this->id ); ?>" <?php echo esc_url( $this->link() ); ?> <?php echo esc_attr( $this->value() ) === $key ? esc_attr( 'checked=checked' ) : ''; ?>>
					<label for="<?php echo esc_attr( $this->id ); ?>[key]"><?php echo esc_html( $value ); ?></label>
				</li>
				<?php
			}

			?>
			 </ul>
			 <?php
		}
	}
}
add_action( 'customize_register', 'stag_customizer_layout_control', 1, 1 );

function stag_customizer_layout_css() {
	wp_register_script( 'customizer-ui-js', get_template_directory_uri() . '/assets/js/customizer-ui.js', 'jquery' );
	wp_enqueue_script( 'customizer-ui-js' );
	?>
	<style type="text/css">
		.customizer-control-row {
			position: relative;
			display: inline-block;
			vertical-align: top;
			width: 82px;
			height: 82px;
			overflow: hidden;
			margin: 0 0 7px 0;
			font: 0/0 a;
		}
		.customizer-control-row:nth-child(2),
		.customizer-control-row:nth-child(3) {
			margin-left: 3px;
		}

		.customizer-control-row:nth-child(1) label { background-image: url("<?php echo get_template_directory_uri(); ?>/assets/img/layout-3.svg"); }
		.customizer-control-row:nth-child(2) label { background-image: url("<?php echo get_template_directory_uri(); ?>/assets/img/layout-1.svg"); }
		.customizer-control-row:nth-child(3) label { background-image: url("<?php echo get_template_directory_uri(); ?>/assets/img/layout-2.svg"); }
		.customizer-control-row:nth-child(4) label { background-image: url("<?php echo get_template_directory_uri(); ?>/assets/img/layout-4.svg"); }

		.customizer-control-row input {
			position: absolute;
			width: 100%;
			height: 100%;
			opacity: 0;
		}
		.customizer-control-row input,
		.customizer-control-row label {
			width: 100%;
		}
		.customizer-control-row label {
			width: 82px;
			height: 82px;
			background-size: 82px;
			display: block;
			box-sizing: border-box;
		}

		.customizer-control-row input[type="radio"]:checked + label {
			opacity: .4;
		}

		#stag-loading {
			background: #333;
			padding: 10px 0;
			color: white;
			width: 40px;
			position: absolute;
			top: 30px;
			right: 30px;
			text-align: center;
		}

		#stag-loading i {
			display: inline-block;
			-webkit-animation: rotate 400ms linear 0s infinite alternate;
			-moz-animation: rotate 400ms linear 0s infinite alternate;
			-ms-animation: rotate 400ms linear 0s infinite alternate;
			animation: rotate 400ms linear 0s infinite alternate;
		}

		@-webkit-keyframes rotate { 0% { -webkit-transform: rotate(0deg); } 100% { -webkit-transform: rotate(180deg); } }
		@-moz-keyframes rotate { 0% { -moz-transform: rotate(0deg); } 100% { -moz-transform: rotate(180deg); } }
		@keyframes rotate { 0% { transform: rotate(0deg); } 100% { transform: rotate(180deg); } }

		.accordion-section .customize-control-image .preview-thumbnail img {
			width: auto;
			height: auto;
		}
	</style>
	<?php
}
add_action( 'customize_controls_print_scripts', 'stag_customizer_layout_css' );

if ( ! function_exists( 'skilt_in_range' ) ) {
	/**
	 * Only allow values between a certain minimum & maximum range.
	 *
	 * @param int $input Input to be sanitized.
	 * @param int $min Minimum number.
	 * @param int $max Maximum number.
	 * @return int   Sanitized input.
	 */
	function skilt_in_range( int $input, int $min, int $max ) {
		if ( $input < $min ) {
			$input = $min;
		}
		if ( $input > $max ) {
			$input = $max;
		}
		return $input;
	}
}

if ( ! function_exists( 'skilt_range_sanitization' ) ) {
	/**
	 * Slider sanitization.
	 *
	 * @param  string $input    Slider value to be sanitized.
	 * @param  object $setting  Settings object.
	 * @return string   Sanitized input
	 */
	function skilt_range_sanitization( $input, $setting ) {
		$attrs  = $setting->manager->get_control( $setting->id )->choices;
		$min    = ( isset( $attrs['min'] ) ? $attrs['min'] : $input );
		$max    = ( isset( $attrs['max'] ) ? $attrs['max'] : $input );
		$number = $input;

		return skilt_in_range( $number, $min, $max );
	}
}

if ( ! function_exists( 'skilt_sanitize_hex_color' ) ) :
	/**
	 * Validates a hex color.
	 *
	 * Returns either '', a 3 or 6 digit hex color (with #), or null.
	 *
	 * @param string $color Hexidecimal value to sanitize.
	 * @return string|null Sanitized value.
	 */
	function skilt_sanitize_hex_color( $color ) {
		if ( '' === $color ) {
			return '';
		}

		// 3 or 6 hex digits, or the empty string.
		if ( preg_match( '|^#([A-Fa-f0-9]{3}){1,2}$|', $color ) ) {
			return $color;
		}

		return null;
	}
endif;

/**
 * Sanitize function for dropdown pages.
 *
 * @param int    $page_id Page ID.
 * @param string $setting Setting ID.
 * @return mixed Page ID.
 */
function skilt_sanitize_dropdown_pages( $page_id, $setting ) {
	// Ensure $input is an absolute integer.
	$page_id = absint( $page_id );

	// If $page_id is an ID of a published page, return it; otherwise, return the default.
	return ( 'publish' === get_post_status( $page_id ) ? $page_id : $setting->default );
}
