<?php
/**
 * @package Stag_Customizer
 */

if ( ! function_exists( 'stag_pf_archive_url' ) ) :
	/**
	 * Return the URL of a post format archive
	 *
	 * @since  1.0.
	 *
	 * @param  string $format    The post format.
	 * @return string               The URL of the post format archive.
	 */
	function stag_pf_archive_url( $format = null ) {
		if ( ! $format ) {
			$format = get_post_format();
		}

		if ( ! $format ) {
			return false;
		}

		return get_post_format_link( $format );
	}
endif;

if ( ! function_exists( 'stag_post_format_icon' ) ) :
	/**
	 * Get Post format icon.
	 *
	 * @since 1.0.0
	 * @param  string $post_format Post format for which to return the icon.
	 * @return string void
	 */
	function stag_post_format_icon( $echo = true ) {
		$post_format = get_post_format();

		if ( ! $post_format ) {
			$post_format = 'standard';
		}

		if ( 'status' === $post_format || 'chat' === $post_format ) {
			return false;
		}

		$icons = apply_filters(
			'stag_post_format_icons',
			array(
				'standard' => 'fa-file-alt',
				'aside'    => 'fa-thumbtack',
				'link'     => 'fa-chain',
				'quote'    => 'far fa-comment',
				'image'    => 'fa-camera-retro',
				'gallery'  => 'fa-image',
				'audio'    => 'fa-volume-up',
				'video'    => 'fa-film',
			)
		);

		$icon = "<i class='fas {$icons[$post_format]} return-to__icon'></i>";

		// Return or echo.
		if ( false === $echo ) {
			return $icon;
		} else { 			echo $icon; // phpcs:ignore
		}   }
endif;
