<?php
/**
 * @package Stag_Customizer
 * @subpackage Starter
 */

if ( ! function_exists( 'stag_css_add_rules' ) ) :
/**
 * Process user options to generate CSS needed to implement the choices.
 *
 * @since 1.0.0.
 *
 * @return void
 */
function stag_css_add_rules() {

	$font_header       = stag_theme_mod( 'font', 'header' );
	$font_header_stack = stag_get_font_stack( $font_header );
	$font_body         = stag_theme_mod( 'font', 'body' );
	$font_body_stack   = stag_get_font_stack( $font_body );

	if ( '' !== $font_header_stack ) {
		stag_get_css()->add( array(
			'selectors' => array(
				'h1', 'h2', 'h3', 'h4', 'h5', 'h6',
				'button',
				'.button',
				'blockquote',
				'.entry-meta',
				'.font-header',
				'.menu-sidebar',
				'.post-meta-info',
				'.comment-author',
				'.entry-taxonomy',
				'.stag-intro-text',
				'.post-navigation',
				'.widget_pages',
				'.widget_nav_menu',
				'.widget_recent_entries a',
				'.intro-page .entry-content',
				'.format-aside .entry-content',
				),
			'declarations' => array(
				'font-family' => $font_header_stack
			)
		) );
	}

	if ( '' !== $font_body_stack ) {
		stag_get_css()->add( array(
			'selectors'    => array( 'body', '.font-body', '.post-likes' ),
			'declarations' => array(
				'font-family' => $font_body_stack
			)
		) );
	}

	/**
	 * Font Sizes
	 */
	// Get and escape options
	$font_body_size   = absint( stag_theme_mod( 'font', 'body-size' ) );
	$font_header_size = absint( stag_theme_mod( 'font', 'header-size' ) );

	if ( $font_body_size !== stag_theme_mod( 'font', 'body-size', true ) ) {
		stag_get_css()->add( array(
			'selectors'    => array( 'body', '.font-body' ),
			'declarations' => array(
				'font-size-px'  => $font_body_size . 'px',
				'font-size-rem' => stag_convert_px_to_rem( $font_body_size ) . 'rem'
			)
		) );
	}

	// Relative font sizes
	$percent = apply_filters( 'stag_font_relative_size', array(
		// Relative to navigation font size
		'sub-menu'     => 93,
		// Relative to header font size
		'h1'           => 100,
		'h2'           => 68,
		'h3'           => 60,
		'h4'           => 54,
		'h5'           => 48,
		'h6'           => 38,
		'post-title'   => 68,
		// Relative to widget font size
		'widget-title' => 100,
		// Relative to body font size
		'comments'     => 88,
		'comment-date' => 82,
	) );

	if ( $font_header_size !== stag_theme_mod( 'font', 'header-size', true ) ) {
		// h1
		stag_get_css()->add( array(
			'selectors'    => array( 'h1', '.font-header' ),
			'declarations' => array(
				'font-size-px'  => $font_header_size . 'px',
				'font-size-rem' => stag_convert_px_to_rem( $font_header_size ) . 'rem'
			)
		) );

		// h2
		stag_get_css()->add( array(
			'selectors'    => array( 'h2' ),
			'declarations' => array(
				'font-size-px'  => stag_get_relative_font_size( $font_header_size, $percent[ 'h2' ] ) . 'px',
				'font-size-rem' => stag_convert_px_to_rem( stag_get_relative_font_size( $font_header_size, $percent[ 'h2' ] ) ) . 'rem'
			)
		) );

		// h3
		stag_get_css()->add( array(
			'selectors'    => array( 'h3' ),
			'declarations' => array(
				'font-size-px'  => stag_get_relative_font_size( $font_header_size, $percent[ 'h3' ] ) . 'px',
				'font-size-rem' => stag_convert_px_to_rem( stag_get_relative_font_size( $font_header_size, $percent[ 'h3' ] ) ) . 'rem'
			)
		) );

		// h4
		stag_get_css()->add( array(
			'selectors'    => array( 'h4' ),
			'declarations' => array(
				'font-size-px'  => stag_get_relative_font_size( $font_header_size, $percent[ 'h4' ] ) . 'px',
				'font-size-rem' => stag_convert_px_to_rem( stag_get_relative_font_size( $font_header_size, $percent[ 'h4' ] ) ) . 'rem'
			)
		) );

		// h5
		stag_get_css()->add( array(
			'selectors'    => array( 'h5' ),
			'declarations' => array(
				'font-size-px'  => stag_get_relative_font_size( $font_header_size, $percent[ 'h5' ] ) . 'px',
				'font-size-rem' => stag_convert_px_to_rem( stag_get_relative_font_size( $font_header_size, $percent[ 'h5' ] ) ) . 'rem'
			)
		) );

		// h6
		stag_get_css()->add( array(
			'selectors'    => array( 'h6' ),
			'declarations' => array(
				'font-size-px'  => stag_get_relative_font_size( $font_header_size, $percent[ 'h6' ] ) . 'px',
				'font-size-rem' => stag_convert_px_to_rem( stag_get_relative_font_size( $font_header_size, $percent[ 'h6' ] ) ) . 'rem'
			)
		) );
	}

	// Body background color
	stag_get_css()->add( array(
		'selectors'    => array( 'body' ),
		'declarations' => array(
			'background-color' => stag_maybe_hash_hex_color( get_theme_mod( 'background_color', '#373f4d' ) )
		)
	) );
	stag_get_css()->add( array(
		'selectors'    => array( '.page-cover' ),
		'declarations' => array(
			'opacity' => stag_theme_mod( 'background_image', 'background-opacity' )
		)
	) );
	stag_get_css()->add( array(
		'selectors'    => array( '.page-cover' ),
		'declarations' => array(
			'background-repeat' => get_theme_mod( 'background_repeat', 'no-repeat' )
		)
	) );
	stag_get_css()->add( array(
		'selectors'    => array( '.page-cover' ),
		'declarations' => array(
			'background-position' => get_theme_mod( 'background_position_x', 'center' )
		)
	) );
	stag_get_css()->add( array(
		'selectors'    => array( '.page-cover' ),
		'declarations' => array(
			'background-attachment' => get_theme_mod( 'background_attachment', 'fixed' )
		)
	) );
	stag_get_css()->add( array(
		'selectors'    => array( '.page-cover' ),
		'declarations' => array(
			'background-size' => stag_theme_mod( 'background_image', 'background-size' )
		)
	) );

	$background_image = get_theme_mod( 'background_image' );
	if ( '' != $background_image ) {
		stag_get_css()->add( array(
			'selectors'    => array( '.page-cover' ),
			'declarations' => array(
				'background-image' => "url($background_image)"
			)
		) );
	}

	// Accent color
	stag_get_css()->add( array(
		'selectors' => array(
			'a',
			'.accent-color',
			'blockquote:before',
			'.post-likes:hover',
			'#posts-wrapper .format-link .entry-title a'
		),
		'declarations' => array(
			'color' => stag_maybe_hash_hex_color( stag_theme_mod( 'colors', 'accent' ) )
		)
	) );

	// Accent background
	stag_get_css()->add( array(
		'selectors' => array(
			'button',
			'.button',
			'.more-link',
			'.accent-background',
			'input[type="reset"]',
			'input[type="submit"]',
			'input[type="button"]'
		),
		'declarations' => array(
			'background-color' => stag_maybe_hash_hex_color( stag_theme_mod( 'colors', 'accent' ) )
		)
	) );


	/**
	 * Header area text color.
	 *
	 * @since 2.0.0.
	 */
	$header_text_color = stag_theme_mod( 'colors', 'header-area-text-color' );
	if ( '#ffffff' != $header_text_color ) {
		stag_get_css()->add( array(
			'selectors'    => array(
				'.intro-page',
				'.intro-page a',
				'.site-header a',
				'.section-header',
				'.author-social-profiles a',
				'.menu-header.menu-header a',
				'.intro-page .entry-content',
				'.stag-social-icons.normal a',
			),
			'declarations' => array(
				'color' => stag_maybe_hash_hex_color( $header_text_color ),
			)
		) );
	}

	/**
	 * Footer area text color.
	 *
	 * @since 2.0.0.
	 */
	$footer_text_color = stag_theme_mod( 'colors', 'footer-area-text-color' );
	if ( '#ffffff' != $footer_text_color ) {
		stag_get_css()->add( array(
			'selectors'    => array(
				'.site-footer',
				'.has-background .site-footer',
				'.site-footer a',
			),
			'declarations' => array(
				'color' => stag_maybe_hash_hex_color( $footer_text_color ),
			)
		) );
	}
}
endif;

add_action( 'stag_css', 'stag_css_add_rules' );

function stag_add_custom_css( $css ) {
	$custom_css = stag_theme_mod( 'styling-options', 'custom-css' );

	if( '' !== $custom_css ) {
		echo $custom_css; // phpcs:ignore
	}

	return false;
}
add_action( 'stag_custom_css', 'stag_add_custom_css', 11 );
