<?php
/**
 * Custom template tags for this theme.
 *
 * Eventually, some of the functionality here could be replaced by core features
 *
 * @package Stag_Customizer
 * @subpackage Skilt
 */

if ( ! function_exists( 'stag_get_read_more_text' ) ) :
/**
 * Convenience function to get the filtered, translated read more string
 *
 * @since 1.0
 *
 * @return string The filtered, translated read more string
 */
function stag_get_read_more_text() {
	return apply_filters( 'stag_read_more_text', __( 'Read More', 'skilt' ) );
}
endif;

if ( ! function_exists( 'stag_comment' ) ) :
/**
 * Template for comments and pingbacks.
 *
 * Used as a callback by wp_list_comments() for displaying the comments.
 */
function stag_comment( $comment, $args, $depth ) {
	$GLOBALS['comment'] = $comment;

	if ( 'pingback' == $comment->comment_type || 'trackback' == $comment->comment_type ) : ?>

	<li id="comment-<?php comment_ID(); ?>" <?php comment_class(); ?>>
		<div class="comment-body">
			<?php _e( 'Pingback:', 'skilt' ); ?> <?php comment_author_link(); ?> <?php edit_comment_link( __( 'Edit', 'skilt' ), '<span class="edit-link">', '</span>' ); ?>
		</div>

	<?php else : ?>

	<li id="comment-<?php comment_ID(); ?>" <?php comment_class( empty( $args['has_children'] ) ? '' : 'parent' ); ?>>
		<article id="div-comment-<?php comment_ID(); ?>" class="comment-body">
			<div class="author-avatar">
				<?php echo get_avatar( $comment ); ?>
			</div>
			<footer class="comment-meta">
				<span class="comment-author vcard">
					<?php comment_author_link(); ?>
				</span><!-- .comment-author -->

				<span class="comment-metadata">
					<a href="<?php echo esc_url( get_comment_link( $comment->comment_ID ) ); ?>">
						<time datetime="<?php comment_time( 'c' ); ?>">
						<?php
							$date_option = stag_theme_mod( 'layout', 'post-date' );
							if ( 'absolute' == $date_option ) {
								echo get_comment_date();
							} else {
								printf(
									__( '%s ago', 'skilt' ),
									human_time_diff( get_comment_time( 'U' ), current_time( 'timestamp' ) )
								);
							}
						?>
						</time>
					</a>
					<?php
						comment_reply_link( array_merge( $args, array(
							'add_below' => 'div-comment',
							'depth'     => $depth,
							'max_depth' => $args['max_depth']
						) ) );
					?>
				</span><!-- .comment-metadata -->

				<?php if ( '0' == $comment->comment_approved ) : ?>
				<p class="comment-awaiting-moderation"><?php _e( 'Your comment is awaiting moderation.', 'skilt' ); ?></p>
				<?php endif; ?>
			</footer><!-- .comment-meta -->

			<div class="comment-content">
				<?php comment_text(); ?>
			</div><!-- .comment-content -->
		</article><!-- .comment-body -->

	<?php
	endif;
}
endif;  // ends check for stag_comment()

function stag_comment_form_filter( $defaults ) {
	$defaults['title_reply'] = __( 'Submit a comment', 'skilt' );

	$input_size = '50';

	// Comment Author
	$comment_author = ( isset( $_POST['author'] ) ) ? wp_strip_all_tags( $_POST['author'], true ) : null;
	$author_field = sprintf(
		'<p class="comment-form-author"><input class="text-input respond-type" type="text" name="%1$s" id="%1$s" value="%3$s" size="%4$d" aria-required="true" tabindex="%5$d" placeholder="%2$s" /></p>',
		'author',
		esc_attr_x( 'Name', 'comment field placeholder', 'skilt' ),
		esc_attr( $comment_author ),
		$input_size,
		1
	);

	// Comment Author Email
	$comment_author_email = ( isset( $_POST['email'] ) ) ? trim( $_POST['email'] ) : null;
	$email_field = sprintf(
		'<p class="comment-form-email"><input class="text-input respond-type" type="email" name="%1$s" id="%1$s" value="%3$s" size="%4$d" aria-required="true" tabindex="%5$d" placeholder="%2$s" /></p>',
		'email',
		esc_attr_x( 'Email', 'comment field placeholder', 'skilt' ),
		esc_attr( $comment_author_email ),
		$input_size,
		2
	);

	// Comment Author URL
	$comment_author_url = ( isset( $_POST['url'] ) ) ? trim( $_POST['url'] ) : null;
	$url_field = sprintf(
		'<p class="comment-form-url"><input class="text-input respond-type" type="url" name="%1$s" id="%1$s" value="%3$s" size="%4$d" tabindex="%5$d" placeholder="%2$s" />',
		'url',
		esc_attr_x( 'Website', 'comment field placeholder', 'skilt' ),
		esc_attr( $comment_author_url ),
		$input_size,
		3
	);

	// Set the fields in the $defaults array
	$defaults['fields'] = array(
		'author' => $author_field,
		'email'  => $email_field,
		'url'    => $url_field
	);

	// Comment Form
	$defaults['comment_field'] = sprintf(
		'<p class="comment-form-comment"><textarea id="comment" class="blog-textarea respond-type" name="comment" cols="58" rows="10" aria-required="true" tabindex="4" placeholder="%s"></textarea></p>',
		esc_attr_x( 'Your Comment', 'comment field placeholder', 'skilt' )
	);

	// Comment form notes
	$defaults['comment_notes_before'] = '';
	$defaults['comment_notes_after']  = '';

	// Submit label
	$defaults['label_submit'] = __( 'Submit comment', 'skilt' );

	return $defaults;
}
add_filter( 'comment_form_defaults', 'stag_comment_form_filter' );

/**
 * Returns true if a blog has more than 1 category
 *
 * @return bool
 */
function stag_categorized_blog() {
	if ( false === ( $all_the_cool_cats = get_transient( '_stag_categories' ) ) ) {
		// Create an array of all the categories that are attached to posts.
		$all_the_cool_cats = get_categories( array(
			'fields'     => 'ids',
			'hide_empty' => 1,

			// We only need to know if there is more than one category.
			'number'     => 2,
		) );

		// Count the number of categories that are attached to the posts.
		$all_the_cool_cats = count( $all_the_cool_cats );

		set_transient( '_stag_categories', $all_the_cool_cats );
	}

	if ( $all_the_cool_cats > 1 ) {
		// This blog has more than 1 category so _s_categorized_blog should return true.
		return true;
	} else {
		// This blog has only 1 category so _s_categorized_blog should return false.
		return false;
	}
}

/**
 * Flush out the transients used in stag_categorized_blog
 */
function stag_category_transient_flusher() {
	// Like, beat it. Dig?
	delete_transient( '_stag_categories' );
}
add_action( 'edit_category', 'stag_category_transient_flusher' );
add_action( 'save_post',     'stag_category_transient_flusher' );

/**
 * Get site layout via theme option.
 *
 * @since 1.0.0.
 *
 * @return string|mixed
 */
function skilt_get_site_layout() {
	return stag_theme_mod( 'styling-options', 'layout' );
}

if ( ! function_exists( 'stag_related_posts' ) ) :
/**
 * Display related posts, based on post tags.
 *
 * Forked from "Ink".
 * @link https://codestag.com/themes/ink
 *
 * @since 1.0.0.
 *
 * @return void
 */
function stag_related_posts() {
	global $post;

	if( ! stag_theme_mod( 'layout', 'related-posts' ) )
		return;

	$tags = wp_get_post_tags( $post->ID );

	if ( count( $tags ) ) {
		$tag_ids = array();

		foreach ( $tags as $individual_tag ) {
			$tag_ids[] = $individual_tag->slug;
		}

		$query = new WP_Query( array(
			'tag'                 => implode(',', $tag_ids),
			'post__not_in'        => array( $post->ID ),
			'posts_per_page'      => absint( stag_theme_mod( 'layout', 'related-posts-count' ) ),
			'ignore_sticky_posts' => true
		) );

		// Add filter to later attach 'post-grid' class to posts for homepage layouts.
		add_filter( 'stag_showing_related_posts', '__return_true' );

		if( $query->have_posts() ) :

			echo '<section id="posts-wrapper" class="related-posts">';

			while( $query->have_posts() ) : $query->the_post();
				get_template_part( 'format', get_post_format() );
			endwhile;

			echo '<div id="gutter-sizer"></div>';
			echo '</section>';

		endif;
	}

	wp_reset_query();

	remove_all_filters( 'stag_showing_related_posts' );
}
endif;

/**
 * Output the primary menu if the current view calls for it.
 *
 * @since 1.0.3.
 *
 * @param string $context The menu location context - header or sidebar.
 *
 * @return void
 */
if ( ! function_exists( 'stag_maybe_show_primary_menu' ) ) :
function stag_maybe_show_primary_menu( $context ) {

	$location     = stag_theme_mod( 'layout', 'navigation-position' );

	$menu_class   = 'primary-menu menu-';
	$menu_class   .= $context;

	$show_sidebar = true;

	if ( 'sidebar' == $context && 'header' == $location ) $menu_class .= ' hide-on-desktop';
	if ( 'header' == $context && 'sidebar' == $location ) $show_sidebar = false;

	if ( true === $show_sidebar && has_nav_menu( 'primary' ) ) :
		wp_nav_menu( array(
			'theme_location' => 'primary',
			'menu_class'     => $menu_class,
			'container'      => false,
			'fallback_cb'    => false
		) );
	endif;
}
endif;

if ( ! function_exists( 'wp_body_open' ) ) {
	/**
	 * Backwards compatibility for wp_body_open.
	 *
	 * @return void.
	 */
	function wp_body_open() {
			do_action( 'wp_body_open' );
	}
}
